/**
 * 添加localStorage 并设置缓存过期时间
 * @param key 唯一标识
 * @param value 值
 * @param expirationMinutes 过期时间(天)
 */
export const localStorageSet = {
  // 存储数据和过期时间
   setItemWithExpiration(key:string, value:any, expirationDays:number) {
    const expirationMS = expirationDays * 24 * 60 * 1000; // 转换为毫秒
    const expirationTime = new Date().getTime() + expirationMS;
    localStorage.setItem(key, JSON.stringify({ value, expirationTime }));
  },

  // 读取数据并检查是否过期
  getItemWithExpiration(key:string) {
    const item = localStorage.getItem(key);
    if (!item) {
      return null; // 数据不存在
    }
    const parsedItem = JSON.parse(item);
    const now = new Date().getTime();

    if (now > parsedItem.expirationTime) {
      localStorage.removeItem(key); // 数据已过期，删除它
      return null;
    }
    return parsedItem.value?.[key] ?? []; // 返回有效数据
  }
}


